@@ -173,5 +173,5 @@ def _init_logger(config: LogConfigure):
     set_extra_to_environ("progname", config.app_name)
 
 
-def init_logger(app_name: str):
-    return _init_logger(LogConfigure(app_name=app_name, cleanup=True))
+def init_logger(app_name: str, level: str = "DEBUG"):
+    return _init_logger(LogConfigure(app_name=app_name, cleanup=True, level=level))
