@@ -33,7 +33,9 @@ class JSONLogFormatter(BaseFormatter):
         if hasattr(record, "payload"):
             json_log_fields["payload"] = record.payload
         elif hasattr(record, "message"):
-            json_log_fields["payload"] = {"message": record.message}
+            msg = record.message % record.args
+            json_log_fields["payload"] = {"message": msg}
         elif hasattr(record, "msg"):
-            json_log_fields["payload"] = {"message": record.msg}
+            msg = record.msg % record.args
+            json_log_fields["payload"] = {"message": msg}
         return json.dumps(json_log_fields, ensure_ascii=False)
