@@ -23,9 +23,12 @@ class SimpleLogFormatter(BaseFormatter):
         if hasattr(record, "tags"):
             log_str += f"{record.tags} "
         if hasattr(record, "message"):
-            log_str += f"{record.message}"
+            msg = record.message % record.args
+            log_str += f"{msg}"
+
         elif hasattr(record, "msg"):
-            log_str += f"{record.msg}"
+            msg = record.msg % record.args
+            log_str += f"{msg}"
 
         if record.exc_info:
             log_str += f"\n{traceback.format_exception(*record.exc_info)}\n"
